#!/usr/bin/perl -w
# +=======================================================================+
# || CipUX::Conversion                                                   ||
# ||                                                                     ||
# || This module provides conversion function for CipUX (CiBot,CAT)      ||
# ||                                                                     ||
# || Copyright (Urheberrecht) 1999 - 2005 by  Christian Kuelker          ||
# || License: GPLv2                                                      ||
# || Revision: 2005-06-11                                                ||
# +=======================================================================+


############################################################################
############################################################################
##                                                                        ##
## WARNING: This Buffer is UTF-8, do not edit with a normal editor!!!     ##
##                                                                        ##
############################################################################
############################################################################

# xemacs utf-8
# ('Edit'->'Mule'->'Set Coding System of Buffer File ...'->'u'[TAB]'utf-8')
# NOT: binary,raw,iso8859-1,iso8859-15
# Or use vi with export LANG="en_US.UTF-8" or similar

package CipUX::Conversion;

use 5.006000;
use strict;
use utf8;
use warnings;

require Exporter;

our @ISA = qw(Exporter);

# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.

# This allows declaration	use CipUX::Conversion ':all';
# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
# will save memory.
our %EXPORT_TAGS = ( 'all' => [ qw(

) ] );

our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );

our @EXPORT = qw(
           &conversion_trim
           &conversion_ascii
           &conversion_integer
           &conversion_german
           &conversion_name
           &conversion_login
           &conversion_password
           &conversion_ldap
           &conversion_mail
);

our $VERSION = '3.002009';


# Preloaded methods go here.

my $SCRIPT  = "CipUX::Conversion";
my $PROJECT = "cipworx";
my $BRAND   = "cipux";
my $VERBOSE = 0;

=pod

=head1 NAME

CipUX::Conversion - Version 3.01

=head1 SYNOPSIS

    use CipUX::Conversion;

=head1 ABSTACT

This module provides conversion functions for
strings used by scripts like add.pl
under CipUX project,
part of CipWorX.

B<Features:>

=over

=item * beautify strings

=back

=head1 REQUIREMENTS

  Date::Calc
 CGI::Carp
 POSIX
 Tie::IxHash
 Getopt::Std
 Getopt::Long
 File::Basename
 Net::IMAP::Simple
 Mail::Header
 MIME::Base64
 File::Find
 Cwd
 DirHandle
 Digest::MD4

=head1 USAGE

Perl scripts which would like to use conversion3.pm should have lines
like the following:

  use CipUX::Conversion;


=head1 WARNINGS

[1] Be sure not changing the coding system of the file conversion3.pm.

[2] If you use this class on other systems than Trustix, be sure it
perform the task as you expect.

Example:

  On Trustix 1.5           : clean_name(KÃ¼lker) -> Kuelker

  On RH 8.0                : clean_name(KÃ¼lker) -> KAlker

  Debian (Sarge) Skolelinux: clean_name(KÃ¼lker) -> Kuelker

=head1 FUNCTION

The perl module CipUX::Conversion provides the following functions:

=cut

# +========================================================================+
# ||                            conversion_trim                           ||
# +========================================================================+

=pod

=head2 conversion_trim

Replace leading and trailing withe space.

B<Syntax:>

  my $new_string = &conversion_trim($old_string);

B<Discussion:>

For Names, Logins and other objects.

=cut

sub conversion_trim{

  my $string = shift;
  my $caller = caller();

  &local_log("WARNING: TRIM input string not defined from [$caller], using empty stringh") if not defined($string);
  $string = "" if not defined($string);

  $string =~ s/^\s+//g;
  $string =~ s/\s+$//g;

  return $string;
}

# +========================================================================+
# ||                            conversion_ascii                          ||
# +========================================================================+

=pod

=head2 conversion_ascii

Delete everything that is not in the range: a-z 0-9 A-Z - _.

B<Syntax:>

  my $new_string = &conversion_ascii($old_string);

B<Discussion:>

For Names, Logins and cn, dn.

=cut

sub conversion_ascii{

  my $string = shift;
  my $caller = caller();

  &local_log("WARNING: ASCII input string not defined from [$caller], using empty string") if not defined($string);
  $string = "" if not defined($string);

  $string =~ s/[^ABCDEFGHIJKLMNOPQRSTUVWXYZZ0123456789abcdefghijklmnopqrstuvwxyz _-]//g;

  return $string;
}

# +========================================================================+
# ||                            conversion_integer                        ||
# +========================================================================+

=pod

=head2 conversion_integer

Delete everything that is not in the range: 0-9.

B<Syntax:>

  my $new_string = &conversion_integer($old_string);

B<Discussion:>

For Names, Logins and cn, dn.

=cut

sub conversion_integer{

  my $string = shift;
  my $caller = caller();

  &local_log("WARNING: INTEGER input string not defined from [$caller], using empty string") if not defined($string);
  $string = "" if not defined($string);

  $string =~ s/[^0123456789]//g;

  return $string;
}


# +========================================================================+
# ||                            conversion_german                         ||
# +========================================================================+

=pod

=head2 conversion_german

Replace umlauts to ASCI equivalents.

B<Syntax:>

  my $new_string = &conversion_german($old_string);

B<Discussion:>

For Names and other objects.

=cut

sub conversion_german{

  my $string = shift;
  my $caller = caller();

  &local_log("WARNING: GERMAN input string not defined from [$caller], using empty string") if not defined($string);
  $string = "" if not defined($string);

  # for german:
  $string =~ s/ü/ue/g; # ü
  $string =~ s/ö/oe/g; # ö
  $string =~ s/ä/ae/g; # ä
  $string =~ s/Ü/Ue/g; # Ü
  $string =~ s/Ö/Oe/g; # Ö
  $string =~ s/Ä/Ae/g; # Ä
  $string =~ s/ß/ss/g; # ß

  return $string;

}

# +========================================================================+
# ||                            conversion_login                          ||
# +========================================================================+

=pod

=head2 conversion_login

Replace every withe space.
# Replace every leading number. (this is not possible for French schools)
Replace every - to _.
Conversion to ASCII.
Lower Case.

B<Syntax:>

  my $new_string = &conversion_login($old_string);

B<Discussion:>

For Logins and cn, dn.

=cut

sub conversion_login{

  my $string = shift;
  my $caller = caller();

  &local_log("WARNING: LOGIN input string not defined from [$caller], using empty string") if not defined($string);
  $string = "" if not defined($string);

  $string = &conversion_trim($string);

  $string = conversion_german($string);
  $string =~ s/\s+//g;
 # $string =~ s/^\d+//g;#this is not possible for French schools
 # $string =~ s/-/_/g;
  $string = conversion_ascii($string);
  $string = lc($string);

  return $string;
}






# +========================================================================+
# ||                            conversion_password                       ||
# +========================================================================+

=pod

=head2 conversion_password

Replace every withe space.
Replace every leading number.
Delete everything which is not in the range: a-z0-9A-Z!#$%&=-_?@+*

B<Syntax:>

  my $new_string = &conversion_password($old_string);

B<Discussion:>

For passwords

=cut

sub conversion_password{

  my $string = shift;
  my $caller = caller();

  &local_log("WARNING: PASSWORD input string not defined from [$caller], using empty string") if not defined($string);
  $string = "" if not defined($string);

  $string = &conversion_trim($string);

  $string =~ s/\s+//g;
#  $string =~ s/^\d+//g;
  $string =~ s/[^a-z0-9A-Z!#$%&=-_?@+*]//g;

  return $string;
}

# +========================================================================+
# ||                            conversion_name                           ||
# +========================================================================+

=pod

=head2 conversion_name

Replace bad chars. (minus,space,apostroph,quotes,umlauts)
Replace space to underscore

B<Syntax:>

  my $new_string = &conversion_name($old_string);

B<Discussion:>

For Names and other objects.

=cut

sub conversion_name{

  my $string = shift;
  my $caller = caller();

  &local_log("WARNING: NAME input string not defined from [$caller], using empty string") if not defined($string);
  $string = "" if not defined($string);

  $string = conversion_german($string);
  $string = conversion_trim($string);
  $string =~ s/-/_/g;
  $string = conversion_ascii($string);

  return $string;
}

# +========================================================================+
# ||                            conversion_ldap                           ||
# +========================================================================+

=pod

=head2 conversion_ldap

Uses conversion_name.
Replace withe space with _.

B<Syntax:>

  my $new_string = &conversion_ldap($old_string);

B<Discussion:>

For Names and other objects in LDAP.

=cut

sub conversion_ldap{

  my $string = shift;
  my $caller = caller();

  &local_log("WARNING: LDAP input string not defined from [$caller], using empty string") if not defined($string);
  $string = "" if not defined($string);

  $string = conversion_name($string);
  $string =~ s/ /_/g;
  $string =~ s/\s+/_/g;
  $string =~ s/_+/_/g;

  return $string;
}


# +========================================================================+
# ||                            conversion_mail                           ||
# +========================================================================+

=pod

=head2 conversion_mail

Delete everything that is not in the range:
"a-z", ",0-9", "A-Z", "-", "_", "." and "@".

B<Syntax:>

  my $new_string = &conversion_mail($old_string);

B<Discussion:>

For mail addresses.

=cut

sub conversion_mail{

  my $string = shift;
  my $caller = caller();

  &local_log("WARNING: MAIL input string not defined from [$caller], using empty string") if not defined($string);
  #print "Converted mail [$string]<br>";
  $string = "" if not defined($string);

  $string = conversion_trim($string);
  $string =~ s/[^a-z0-9A-Z\@\._-]//g;
  #print "Converted mail [$string]";

  return $string;
}


# +========================================================================+
# ||                            local_log                                 ||
# +========================================================================+

=pod

=head2 local_log

A local log function, wich writes to /var/log/cipux/conversion3.log

B<Syntax:>

  &local_log($message);

B<Discussion:>

We should not use cipot3.pm for this, to much overhaed.

=cut

sub local_log{

  my $message = shift;

  my $file = "/var/log/cipux/$SCRIPT.log";

  open(LOG,">>$file") or die "Can't write to : [$file]\n";

  print LOG "$SCRIPT: $message\n";

  close(LOG);

}

1;

__END__

#===========================================================================
#==== Documentation ========================================================
#===========================================================================

=pod

=head1 SEE ALSO

See the CipUX webpage and the  manual at L<http://www.cipux.org>
See the mailing list L<http://www.cipux.org/mailman/listinfo/>

=head1 AUTOR

Author Christian Kuelker <christian.kuelker@cipworx.org>

=head1 COPYRIGHT AND LICENSE

Copyright (c) 1999-2005 by Christian Kuelker

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2, or (at
your option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA

=cut
