#!/usr/bin/perl -w
# +=======================================================================+
# || "<[CIBOT::DIR]>"/lib/structure.pm
# || Version "<[CIBOT::VERSION]>"
# || This module reads variables from a preference file.
# || The variables can be imported by CipUX CiBot scripts.
# || 1999 - 2005 Christian Kuelker
# || License: GPLv2
# || Revision: 2005-01-02
# +=======================================================================+
# META: replace mkdir
# META: sub for password input (see comments in set_value.pl)


=pod

=head1 NAME

structure.pm - Version "<[CIBOT::VERSION]>"  2003-08-24 CipUX

=head1 SYNOPSIS

    use structure.pm;

=head1 ABSTACT

This module provides structure variables for serveral
perl scrips from cibot family under CipUX project,
part of CipWorX.

=head1 REQUIREMENTS

    strict
    vars
    Exporter

=head1 USAGE

Perl scripts witch would like to use structure.pm should have lines
like the following:

  use lib "../lib";
  require structure.pm;

or

  use lib "../lib";
  require structure.pm qw(get_variables);


=head1 FUNCTION

The perl module structure.pm provides the following variables:

=cut

package structure;
require 5.00600;

#===========================================================================
#=== This is the 'structure' Class (Version <VERSION>) =========================
#===========================================================================
#
# Copyright (c) 2001-05-31, 2002, 2003
# Author Christian Klker <christian.kuelker@cipworx.org>
#
# Copying policy: GPLv2
# Christian Klker <christian.kuelker@cipworx.org>
#

use strict;
use vars  qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);

use Exporter;
@ISA=qw(Exporter);

@EXPORT_OK = qw(&test_structure);

@EXPORT = qw(&test_structure);

our $VERSION = "3.002009"


my $BRAND    = "cipworx";
my $PROJECT  = "cipux";
my $SCRIPT   = "structure.pm";
my $VERBOSE  = 0;# META: if set, list.pl will give verbose list not user list
my $DEBUG    = 1;
my $LANGUAGE = "en";
my $PART     = "Global";
my $Log_File = "";
my $That_Packet = "";

# redirect error message to a logfile
if($DEBUG){

  my $dir      = "/var/log/$PROJECT";
  if(!-d $dir){mkdir($dir,700)}

  #$dir         .= "/$PROJECT";
  #if(!-d $dir){mkdir($dir,700)}

  $Log_File = $dir."/".$SCRIPT.".log";

  open(LOG, ">>$Log_File")
    or die "Can't append to '$Log_File' $!\n";
  my $date = `/bin/date`;
  chomp($date);
  $That_Packet = caller();
  print LOG "="x76;
  print LOG "\n (Error will be written above!)\n";
  print LOG "[$SCRIPT] BEGIN normal operations at $date\n";
  print LOG "[$SCRIPT] BEGIN was called from [$That_Packet]\n";

}

END{
  if($DEBUG){
    my $date = `/bin/date`;
    chomp($date);
    print LOG "[$SCRIPT] END was called from [$That_Packet]\n";
    print LOG "[$SCRIPT] END normal operations at $date\n";
    my $s="="x76;
    print LOG "$s\n\n";
    close(LOG);
  }
}

# +========================================================================+
# ||                            test_structure                            ||
# +========================================================================+

=pod

=head2 &test_structure

  $value = &test_structure();

=cut

sub test_structure{

return 1;

}

# +========================================================================+
# ||                            $structure                                ||
# +========================================================================+

=pod

=head2 $structure

  $structure = 1;

=cut

my $structure = 1;



1;
